package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallFeedback;

/**
 * 意见反馈Mapper接口
 * 
 * @author chang
 * @date 2021-11-25
 */
public interface MallFeedbackMapper 
{
    /**
     * 查询意见反馈
     * 
     * @param id 意见反馈主键
     * @return 意见反馈
     */
    public MallFeedback selectMallFeedbackById(Long id);

    /**
     * 查询意见反馈列表
     * 
     * @param mallFeedback 意见反馈
     * @return 意见反馈集合
     */
    public List<MallFeedback> selectMallFeedbackList(MallFeedback mallFeedback);

    /**
     * 新增意见反馈
     * 
     * @param mallFeedback 意见反馈
     * @return 结果
     */
    public int insertMallFeedback(MallFeedback mallFeedback);

    /**
     * 修改意见反馈
     * 
     * @param mallFeedback 意见反馈
     * @return 结果
     */
    public int updateMallFeedback(MallFeedback mallFeedback);

    /**
     * 删除意见反馈
     * 
     * @param id 意见反馈主键
     * @return 结果
     */
    public int deleteMallFeedbackById(Long id);

    /**
     * 批量删除意见反馈
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallFeedbackByIds(Long[] ids);
}
